@@ -19,7 +19,6 @@ from suite_py.commands.ip import IP
 from suite_py.commands.merge_pr import MergePR
 from suite_py.commands.open_pr import OpenPR
 from suite_py.commands.project_lock import ProjectLock
-from suite_py.commands.rollback import Rollback
 from suite_py.commands.status import Status
 from suite_py.commands.aggregator import Aggregator
 from suite_py.commands.secret import Secret
@@ -129,11 +128,30 @@ def cli_merge_pr(obj):
     MergePR(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("release", help="Create a github release")
+@main.group("release", help="Manage releases")
+def release():
+    pass
+
+
+@release.command("create", help="Create a github release")
 @click.option("--deploy", is_flag=True, help="Trigger deploy after release creation")
 @click.pass_obj
-def cli_release(obj, deploy):
-    Release(obj["project"], deploy, obj["config"], obj["tokens"]).run()
+def cli_release_create(obj, deploy):
+    Release(
+        "create", obj["project"], obj["config"], obj["tokens"], flags={"deploy": deploy}
+    ).run()
+
+
+@release.command("deploy", help="Deploy a github release")
+@click.pass_obj
+def cli_release_deploy(obj):
+    Release("deploy", obj["project"], obj["config"], obj["tokens"]).run()
+
+
+@release.command("rollback", help="Rollback a deployment")
+@click.pass_obj
+def cli_release_rollback(obj):
+    Release("rollback", obj["project"], obj["config"], obj["tokens"]).run()
 
 
 @main.command("deploy", help="Deploy master branch in production")
@@ -142,12 +160,6 @@ def cli_deploy(obj):
     Deploy(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("rollback", help="Rollback in production")
-@click.pass_obj
-def cli_rollback(obj):
-    Rollback(obj["project"], obj["config"], obj["tokens"]).run()
-
-
 @main.command("status", help="Current status of a project")
 @click.pass_obj
 def cli_status(obj):
@@ -177,7 +189,7 @@ def cli_ip(obj, environment):
 @main.command("generator", help="Generate different files from templates")
 @click.pass_obj
 def cli_generator(obj):
-    Generator(obj["config"], obj["tokens"]).run()
+    Generator(obj["project"], obj["config"], obj["tokens"]).run()
 
 
 @main.command("aggregator", help="Manage CNAMEs of aggregators in QA envs")
@@ -193,6 +205,9 @@ def cli_aggregator(obj, show_list, change):
 )
 @click.option("-c", "--create", "create_action", required=False, count=True)
 @click.option("-g", "--grant", "grant_action", required=False, count=True)
+@click.option("-b", "--base-profile", "base_profile", required=False)
 @click.pass_obj
-def cli_secret(obj, create_action, grant_action):
-    Secret(obj["project"], obj["config"], create_action, grant_action).run()
+def cli_secret(obj, create_action, grant_action, base_profile):
+    Secret(
+        obj["project"], obj["config"], create_action, grant_action, base_profile
+    ).run()
