@@ -6,7 +6,7 @@ from github import GithubException
 from suite_py.commands.ask_review import AskReview
 from suite_py.lib import logger
 from suite_py.lib.handler import prompt_utils
-from suite_py.lib.handler.git_handler import GitHandler
+from suite_py.lib.handler.git_handler import GitHandler, get_commit_logs
 from suite_py.lib.handler.github_handler import GithubHandler
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 
@@ -23,26 +23,28 @@ class OpenPR:
 
     def run(self):
         if not self._git.remote_branch_exists(self._branch_name):
-            logger.warning(f"Non ho trovato il branch {self._branch_name} su GitHub")
-            if prompt_utils.ask_confirm("Vuoi commitare tutti i file e pusharlo?"):
+            logger.warning(f"No branch named {self._branch_name} found on GitHub")
+            if prompt_utils.ask_confirm(
+                "Do you want to commit all the files and push them?"
+            ):
                 self._git.add()
                 self._git.commit("Initial commit")
                 self._git.push(self._branch_name)
             else:
-                logger.error("Per favore esegui un 'git push' manualmente")
+                logger.error("Please, run 'git push' manually")
                 sys.exit(-1)
 
         pulls = self._github.get_pr_from_branch(self._project, self._branch_name)
         if pulls.totalCount:
             pr = pulls[0]
             logger.info(
-                f"Esiste una pull request su GitHub per il branch {self._branch_name}"
+                f"There is a pull request on GitHub for the branch {self._branch_name}"
             )
 
             if prompt_utils.ask_confirm(
-                "Vuoi modificare la description della pull request?"
+                "Do you want to change the description of the pull request?"
             ):
-                _edit_pr(pr)
+                self._edit_pr(pr)
             sys.exit(0)
 
         youtrack_id = self._get_youtrack_id()
@@ -55,25 +57,25 @@ class OpenPR:
             return youtrack_id
 
         logger.warning(
-            "Non sono riuscito a trovare una issue YouTrack nel nome del branch o la issue indicata non esiste"
+            "Couldn't find a YouTrack issue in the branch name or the selected issue does not exist"
         )
-        if prompt_utils.ask_confirm("Vuoi collegare la pull request con una issue?"):
+        if prompt_utils.ask_confirm(
+            "Do you want to link the pull request with an issue?"
+        ):
             return self._ask_for_card_id()
         return None
 
     def _ask_for_card_id(self):
-        card_id = prompt_utils.ask_questions_input(
-            "Inserisci ID della card (ex: PRIMA-1234): "
-        )
+        card_id = prompt_utils.ask_questions_input("Enter card ID (ex: PRIMA-1234): ")
         if self._youtrack.validate_issue(card_id):
             return card_id
-        logger.error("ID non esistente su YouTrack")
+        logger.error("ID does not exist on YouTrack")
         return self._ask_for_card_id()
 
     def _create_pr(self, youtrack_id):
         if youtrack_id:
             logger.info(
-                f"Creo una pull request sul progetto {self._project} per il branch {self._branch_name} collegato con la card {youtrack_id}"
+                f"Creating pull request on the {self._project} project for the {self._branch_name} branch linked with the {youtrack_id} card"
             )
             link = self._youtrack.get_link(youtrack_id)
             title = (
@@ -81,67 +83,68 @@ class OpenPR:
             )
         else:
             logger.warning(
-                f"Creo una pull request sul progetto {self._project} per il branch {self._branch_name} SENZA collegamenti a YouTrack"
+                f"Creating pull request on the {self._project} project for the {self._branch_name} branch NOT linked to YouTrack card"
             )
             link = ""
             title = _ask_for_title()
 
-        base_branch = _ask_for_base_branch()
-        pr_body = _ask_for_description()
+        base_branch = self._ask_for_base_branch()
+        pr_body = self._ask_for_description("", base_branch)
 
         body = f"{link} \n\n {pr_body}"
 
         is_draft = prompt_utils.ask_confirm(
-            "Vuoi aprire la pull request come draft?", default=False
+            "Do you want to open the pull request as a draft?", default=False
         )
 
         try:
             pr = self._github.create_pr(
                 self._project, self._branch_name, title, body, base_branch, is_draft
             )
-            logger.info(f"Pull request numero {pr.number} creata! {pr.html_url}")
+            logger.info(f"Pull request with number {pr.number} created! {pr.html_url}")
         except GithubException as e:
-            logger.error("Errore durante la richiesta a GitHub: ")
+            logger.error("Error during GitHub invocation: ")
             logger.error(e.data["errors"][0])
             sys.exit(-1)
 
         if youtrack_id:
             self._youtrack.comment(youtrack_id, f"PR {self._project} -> {pr.html_url}")
-            logger.info(f"Inserito link della pull request nella card {youtrack_id}")
+            logger.info(f"Added the pull request link in the card {youtrack_id}")
 
-        if prompt_utils.ask_confirm("Vuoi inserire i reviewers?"):
+        if prompt_utils.ask_confirm("Do you want to insert reviewers?"):
             AskReview(self._project, self._config, self._tokens).run()
 
+    def _edit_pr(self, pr):
+        pr_body = self._ask_for_description(pr.body, pr.base.ref)
+        pr.edit(body=pr_body)
+        logger.info("Pull request modified")
 
-def _edit_pr(pr):
-    pr_body = _ask_for_description(pr.body)
-    pr.edit(body=pr_body)
-    logger.info("Pull request modificata")
+    def _ask_for_base_branch(self):
+        branch = prompt_utils.ask_questions_input(
+            "Enter the base branch of the pull request: ", "master"
+        )
+        return branch
 
-
-def _ask_for_base_branch():
-    branch = prompt_utils.ask_questions_input(
-        "Inserisci il base branch della pull request: ", "master"
-    )
-    return branch
-
-
-def _ask_for_description(pr_body=""):
-    input(
-        "Inserisci la description della pull request. Premendo invio si aprira l'editor di default"
-    )
-    description = prompt_utils.ask_questions_editor(
-        "Inserisci la description della PR: ", pr_body
-    )
-    if description == "":
-        logger.warning("La descrizione della pull request non può essere vuota")
-        return _ask_for_description(pr_body)
-    return description
+    def _ask_for_description(self, pr_body, base_branch):
+        if pr_body == "" and self._config.user["use_commits_in_pr_body"]:
+            commit_list = get_commit_logs(base_branch)
+            commit_list.reverse()
+            pr_body = "\n---\n".join(commit_list)
+        input(
+            "Enter the description of the pull request. Pressing enter will open the default editor"
+        )
+        description = prompt_utils.ask_questions_editor(
+            "Enter the description of the PR: ", pr_body
+        )
+        if description == "":
+            logger.warning("The description of the pull request cannot be empty")
+            return self._ask_for_description(pr_body, base_branch)
+        return description
 
 
 def _ask_for_title():
-    title = prompt_utils.ask_questions_input("Inserisci il titolo della pull request: ")
+    title = prompt_utils.ask_questions_input("Enter the title of the pull request: ")
     if title == "":
-        logger.warning("Il titolo della pull request non può essere vuoto")
+        logger.warning("The title of the pull request cannot be empty")
         return _ask_for_title()
     return title
