@@ -32,12 +32,18 @@ class Release:
         self._repo = self._github.get_repo(project)
         self._git = GitHandler(project, config)
         self._drone = DroneHandler(config, tokens, repo=project)
-        self._countries = self._parse_available_countries()
+        self._countries = _parse_available_countries(self._drone)
 
     def run(self):
         self._stop_if_prod_locked()
         self._git.fetch()
 
+        if len(self._countries) == 0:
+            logger.error(
+                "Can't determine which countries can be deployed. Try to run `suite-py deploy` instead."
+            )
+            sys.exit(1)
+
         if self._action == "create":
             self._create()
         elif self._action == "deploy":
@@ -45,29 +51,6 @@ class Release:
         else:
             self._rollback()
 
-    def _parse_available_countries(self):
-        pipelines = self._drone.parse_yaml()
-
-        if pipelines is None:
-            logger.error("The file .drone.yml was not found. Unable to continue.")
-            sys.exit(1)
-
-        countries = []
-        REGEX = re.compile(r"deploy-([a-z]+)-.*")
-        for pipeline in pipelines:
-            if "name" in pipeline:
-                c = REGEX.findall(pipeline["name"])
-                if len(c) > 0 and c[0] is not None and c[0] not in countries:
-                    countries.append(c[0])
-
-        if len(countries) == 0:
-            logger.error(
-                "Can't determine which countries can be deployed. Try to run `suite-py deploy` instead."
-            )
-            sys.exit(1)
-
-        return countries
-
     def _get_latest(self):
         tags = self._repo.get_tags()
         tag = git.get_last_tag_number(tags)
@@ -339,3 +322,21 @@ def _check_migrations_deploy(commits):
             "Are you sure you want to continue?", default=False
         ):
             sys.exit()
+
+
+def _parse_available_countries(drone):
+    pipelines = drone.parse_yaml()
+
+    if pipelines is None:
+        logger.error("The file .drone.yml was not found. Unable to continue.")
+        sys.exit(1)
+
+    countries = []
+    REGEX = re.compile(r"deploy-([a-z]+)-.*")
+    for pipeline in pipelines:
+        if "name" in pipeline:
+            c = REGEX.findall(pipeline["name"])
+            if len(c) > 0 and c[0] is not None and c[0] not in countries:
+                countries.append(c[0])
+
+    return countries
